package com.ztmap.project.zhny.strategycondition.mapper;

import java.util.List;
import com.ztmap.project.zhny.strategycondition.domain.TStrategyCondition;

/**
 * 策略条件Mapper接口
 * 
 * @author ztmap
 * @date 2023-10-11
 */
public interface TStrategyConditionMapper 
{
    /**
     * 查询策略条件
     * 
     * @param id 策略条件ID
     * @return 策略条件
     */
    public TStrategyCondition selectTStrategyConditionById(Long id);

    /**
     * 查询策略条件列表
     * 
     * @param tStrategyCondition 策略条件
     * @return 策略条件集合
     */
    public List<TStrategyCondition> selectTStrategyConditionList(TStrategyCondition tStrategyCondition);

    /**
     * 新增策略条件
     * 
     * @param tStrategyCondition 策略条件
     * @return 结果
     */
    public int insertTStrategyCondition(TStrategyCondition tStrategyCondition);

    /**
     * 修改策略条件
     * 
     * @param tStrategyCondition 策略条件
     * @return 结果
     */
    public int updateTStrategyCondition(TStrategyCondition tStrategyCondition);

    /**
     * 删除策略条件
     * 
     * @param id 策略条件ID
     * @return 结果
     */
    public int deleteTStrategyConditionById(Long id);

    /**
     * 批量删除策略条件
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTStrategyConditionByIds(String[] ids);
}
